dgxa100

package
v0.13.3-1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 8, 2026 License: Apache-2.0 Imports: 3 Imported by: 7

Documentation

Index

Constants

This section is empty.

Variables

var (
	MIGProfiles = struct {
		GpuInstanceProfiles     map[int]nvml.GpuInstanceProfileInfo
		ComputeInstanceProfiles map[int]map[int]nvml.ComputeInstanceProfileInfo
	}{
		GpuInstanceProfiles:     gpus.A100_SXM4_40GB.MIGProfiles.GpuInstanceProfiles,
		ComputeInstanceProfiles: gpus.A100_SXM4_40GB.MIGProfiles.ComputeInstanceProfiles,
	}

	MIGPlacements = struct {
		GpuInstancePossiblePlacements     map[int][]nvml.GpuInstancePlacement
		ComputeInstancePossiblePlacements map[int]map[int][]nvml.ComputeInstancePlacement
	}{
		GpuInstancePossiblePlacements:     gpus.A100_SXM4_40GB.MIGProfiles.GpuInstancePlacements,
		ComputeInstancePossiblePlacements: gpus.A100_SXM4_40GB.MIGProfiles.ComputeInstancePlacements,
	}
)

Legacy globals for backward compatibility - expose the internal data

Functions

This section is empty.

Types

type ComputeInstance deprecated

type ComputeInstance = server.ComputeInstance

ComputeInstance is a type alias for server.ComputeInstance maintained for backward compatibility.

Deprecated: This type alias is maintained for backward compatibility only. The type may be removed in a future version.

func NewComputeInstance

func NewComputeInstance(info nvml.ComputeInstanceInfo) *ComputeInstance

type CudaComputeCapability deprecated

type CudaComputeCapability = server.CudaComputeCapability

CudaComputeCapability is a type alias for server.CudaComputeCapability maintained for backward compatibility.

Deprecated: This type alias is maintained for backward compatibility only. The type may be removed in a future version.

type Device deprecated

type Device = server.Device

Device is a type alias for server.Device maintained for backward compatibility.

Deprecated: This type alias is maintained for backward compatibility only. The type may be removed in a future version.

func NewDevice

func NewDevice(index int) *Device

type GpuInstance deprecated

type GpuInstance = server.GpuInstance

GpuInstance is a type alias for server.GpuInstance maintained for backward compatibility.

Deprecated: This type alias is maintained for backward compatibility only. The type may be removed in a future version.

func NewGpuInstance

func NewGpuInstance(info nvml.GpuInstanceInfo) *GpuInstance

type Server deprecated

type Server = server.Server

Server is a type alias for server.Server maintained for backward compatibility.

Deprecated: This type alias is maintained for backward compatibility only. The type may be removed in a future version.

func New

func New() *Server

func NewWithGPUs

func NewWithGPUs(gpus ...gpus.Config) *Server

Jump to