Documentation
¶
Index ¶
- Variables
- type ComputeInstancedeprecated
- type CudaComputeCapabilitydeprecated
- type Devicedeprecated
- type GpuInstancedeprecated
- type Serverdeprecated
Constants ¶
This section is empty.
Variables ¶
var ( MIGProfiles = struct { GpuInstanceProfiles map[int]nvml.GpuInstanceProfileInfo ComputeInstanceProfiles map[int]map[int]nvml.ComputeInstanceProfileInfo }{ GpuInstanceProfiles: gpus.A100_SXM4_40GB.MIGProfiles.GpuInstanceProfiles, ComputeInstanceProfiles: gpus.A100_SXM4_40GB.MIGProfiles.ComputeInstanceProfiles, } MIGPlacements = struct { GpuInstancePossiblePlacements map[int][]nvml.GpuInstancePlacement ComputeInstancePossiblePlacements map[int]map[int][]nvml.ComputeInstancePlacement }{ GpuInstancePossiblePlacements: gpus.A100_SXM4_40GB.MIGProfiles.GpuInstancePlacements, ComputeInstancePossiblePlacements: gpus.A100_SXM4_40GB.MIGProfiles.ComputeInstancePlacements, } )
Legacy globals for backward compatibility - expose the internal data
Functions ¶
This section is empty.
Types ¶
type ComputeInstance
deprecated
type ComputeInstance = server.ComputeInstance
ComputeInstance is a type alias for server.ComputeInstance maintained for backward compatibility.
Deprecated: This type alias is maintained for backward compatibility only. The type may be removed in a future version.
func NewComputeInstance ¶
func NewComputeInstance(info nvml.ComputeInstanceInfo) *ComputeInstance
type CudaComputeCapability
deprecated
type CudaComputeCapability = server.CudaComputeCapability
CudaComputeCapability is a type alias for server.CudaComputeCapability maintained for backward compatibility.
Deprecated: This type alias is maintained for backward compatibility only. The type may be removed in a future version.
type Device
deprecated
type GpuInstance
deprecated
type GpuInstance = server.GpuInstance
GpuInstance is a type alias for server.GpuInstance maintained for backward compatibility.
Deprecated: This type alias is maintained for backward compatibility only. The type may be removed in a future version.
func NewGpuInstance ¶
func NewGpuInstance(info nvml.GpuInstanceInfo) *GpuInstance
type Server
deprecated
Server is a type alias for server.Server maintained for backward compatibility.
Deprecated: This type alias is maintained for backward compatibility only. The type may be removed in a future version.